@@ -208,21 +208,27 @@ QString ExportManager::truncatedFilename(QString const &filename) const
 QString ExportManager::formattedFilename(const QString &nameTemplate) const
 {
     const QDateTime timestamp = m_timestamp;
-    QString baseName = nameTemplate;
+    QString result = nameTemplate;
     QString baseDir = defaultSaveLocation();
-    QString title = m_windowTitle;
 
-    if (!title.isEmpty()) {
+    if (!m_windowTitle.isEmpty()) {
+        QString title = m_windowTitle;
         title.replace(u'/', u'_'); // POSIX doesn't allow "/" in filenames
+        result.replace("<title>"_L1, title);
     } else {
-        // Remove <title> with separators around it
-        const auto wordSymbol = uR"(\p{L}\p{M}\p{N})"_s;
-        const auto separator = u"([^%1]+)"_s.arg(wordSymbol);
-        const auto re = QRegularExpression(u"(.*?)(%1<title>|<title>%1)(.*?)"_s.arg(separator));
-        baseName.replace(re, uR"(\1\5)"_s);
+        // We exclude word characters from being counted as separators.
+        static const auto wordSymbol = uR"(\p{L}\p{M}\p{N})"_s;
+        // Match 1 or more separator characters followed by <title>
+        // We exclude potential ends of tokens to protect tokens before <title>.
+        static const auto match1 = u"[^%1>]+<title>"_s.arg(wordSymbol);
+        // Match <title> followed by 0 or more separator characters
+        // We exclude potential beginnings of tokens to protect tokens after <title>.
+        static const auto match2 = u"<title>[^%1<]*"_s.arg(wordSymbol);
+        // If matching %1, then match %1, else match %2
+        static const QRegularExpression re(u"(?(?=%1)%1|%2)"_s.arg(match1, match2));
+        result.remove(re);
     }
 
-    QString result = baseName;
     const auto &locale = QLocale::system();
     // QDateTime
     for (auto it = filenamePlaceholders.cbegin(); it != filenamePlaceholders.cend(); ++it) {
@@ -237,7 +243,6 @@ QString ExportManager::formattedFilename(const QString &nameTemplate) const
     result.replace("<h>"_L1, timestamp.toString(u"hAP"_s).chopped(2));
     result.replace("<hh>"_L1, timestamp.toString(u"hhAP"_s).chopped(2));
     result.replace("<UnixTime>"_L1, QString::number(timestamp.toSecsSinceEpoch()));
-    result.replace("<title>"_L1, title);
 
     // check if basename includes %[N]d token for sequential file numbering
     QRegularExpression paddingRE;
