@@ -8,6 +8,7 @@
 
 #include "VideoPlatform.h"
 #include <PipeWireRecord>
+#include <QFuture>
 #include <memory>
 
 class Screencasting;
@@ -25,7 +26,7 @@ public:
 
     RecordingModes supportedRecordingModes() const override;
     Formats supportedFormats() const override;
-    void startRecording(const QUrl &fileUrl, RecordingMode recordingMode, const QVariant &option, bool includePointer) override;
+    void startRecording(const QUrl &fileUrl, RecordingMode recordingMode, const QVariantMap &options, bool includePointer) override;
     void finishRecording() override;
 
     Format formatForEncoder(PipeWireBaseEncodedStream::Encoder encoder) const;
@@ -38,4 +39,5 @@ private:
 
     Screencasting *const m_screencasting;
     std::unique_ptr<PipeWireRecord> m_recorder;
+    QFuture<void> m_recorderFuture;
 };
